
enum BUTTON {
    //% block="a"
    'A',
    //% block="b"
    'B'
}

//% color="#ff8000" iconWidth=50 iconHeight=40
namespace kerasMLOC{

    

    //% block="导入训练好的ONNX模型 路径[PATH]" blockType="command"
    //% PATH.shadow="string" PATH.defl="tudou.onnx"
    export function saveImage(parameter: any, block: any) {
        let path=parameter.PATH.code;
        Generator.addImport(`import onnxruntime as rt\nimport numpy as np\nimport BaseData`)
        Generator.addDeclaration("def",`def onnx_cls(img):
    sess = rt.InferenceSession(${path}, None)
    input_name = sess.get_inputs()[0].name
    out_name = sess.get_outputs()[0].name
    dt = BaseData.ImageData(img, size=(224, 224))
    input_data = dt.to_tensor()
    pred_onx = sess.run([out_name], {input_name: input_data})
    result = np.argmax(pred_onx[0], axis=1)[0]
    return result
`)
    }

    //% block="调用ONNX模型识别图像[IMG] 返回结果id" blockType="reporter"
    //% IMG.shadow="normal" IMG.defl="img"
    export function disImg(parameter: any, block: any) {
        let img=parameter.IMG.code;
    
        Generator.addCode(`onnx_cls(${img})`);
    }

        //% block="---"
        export function noteSep1() {

        }
    

    //% block="OpenCV初始化打开摄像头直到成功 编号[CAMNUM]" blockType="command"
    //% CAMNUM.shadow="number" CAMNUM.defl="-1"
    export function readcap(parameter: any, block: any) {
        let num=parameter.CAMNUM.code;
 
        Generator.addImport(`import cv2\nimport numpy as np`)
        
        Generator.addCode(`cap = cv2.VideoCapture(${num})`)
        Generator.addCode(`cap.set(cv2.CAP_PROP_FRAME_WIDTH, 240)`)
        Generator.addCode(`cap.set(cv2.CAP_PROP_FRAME_HEIGHT, 320)`)
        Generator.addCode(`cap.set(cv2.CAP_PROP_BUFFERSIZE, 1)`)
        Generator.addCode(`cv2.namedWindow('cvwindow',cv2.WND_PROP_FULLSCREEN)`)
        Generator.addCode(`cv2.setWindowProperty('cvwindow', cv2.WND_PROP_FULLSCREEN, cv2.WINDOW_FULLSCREEN)`)       
    Generator.addCode(`while not cap.isOpened():
    continue`)    
    }


    //% block="获取摄像头当前帧 赋值给变量[IMG]" blockType="command"
    //% IMG.shadow="normal" IMG.defl="img"
    export function readcapcapture(parameter: any, block: any) {
        let img=parameter.IMG.code;
        Generator.addCode(`${img}_success, ${img} = cap.read()`)

    }

    //% block="图像[IMG]旋转90度横屏" blockType="command"
    //% IMG.shadow="normal" IMG.defl="img"
    export function rotateImg(parameter: any, block: any) {
        let img=parameter.IMG.code;
        Generator.addCode(`${img} = cv2.rotate(${img}, cv2.ROTATE_90_COUNTERCLOCKWISE) `)

    }

    //% block="在图像[IMG]上绘制文字[TEXT] 颜色[COLOR] 坐标X[X]Y[Y] 字号[FSIZE]" blockType="command"
    //% IMG.shadow="normal" IMG.defl="img"
    //% TEXT.shadow="string" TEXT.defl="id1"
    //% COLOR.shadow="colorPalette" 
    //% X.shadow="number"   X.defl="10"
    //% Y.shadow="number"   Y.defl="20"
    //% FSIZE.shadow="number"   FSIZE.defl="40"
    export function drawText(parameter: any, block: any) {
        let img=parameter.IMG.code;
        let txt=parameter.TEXT.code;
        let color=parameter.COLOR.code;
        let x=parameter.X.code;
        let y=parameter.Y.code;
        let fsize=parameter.FSIZE.code;

        var r = 0;
        var g = 0;
        var b = 0;
        try {
            if ( color.length == 8 ) {//分别截取RGB值然后转换为数字值
                r = parseInt(color.substring(2, 4), 16);
                g = parseInt(color.substring(4, 6), 16);
                b = parseInt(color.substring(6, 8), 16);
            }
        } catch(e) {
            return '';
        }

        
        Generator.addImport(`from PIL import ImageFont, ImageDraw, Image`)
        Generator.addDeclaration("drawChineseFunction",`def drawChinese(text,x,y,size,r, g, b, a,img):
    font = ImageFont.truetype("HYQiHei_50S.ttf", size)
    img_pil = Image.fromarray(img)
    draw = ImageDraw.Draw(img_pil)
    draw.text((x,y), text, font=font, fill=(b, g, r, a))
    frame = np.array(img_pil)
    return frame
`)

    Generator.addCode(`${img} = drawChinese(text=${txt},x=${x},y=${y},size=${fsize},r=${r},g=${g},b=${b},a=50,img=${img})`)     
    }

    

    //% block="将图像[IMG]显示到屏幕上" blockType="command"
    //% IMG.shadow="normal" IMG.defl="img"
    export function imShowVideo(parameter: any, block: any) {
        let img=parameter.IMG.code;
        Generator.addCode(`cv2.imshow('cvwindow', ${img})\ncv2.waitKey(2)`)
    }

    //% block="按钮[BUTTON]被按下?" blockType="boolean"
    //% BUTTON.shadow="string" BUTTON.defl="a"
    export function btPress(parameter: any, block: any) {
        let bt=parameter.BUTTON.code;
        Generator.addCode(`(cv2.waitKey(5) & 0xFF == ord(${bt}))`)
    }



    function replaceQuotationMarks(str:string){
            str=str.replace(/"/g, ""); //去除所有引号
            return str
    }


    
}
